@@ -73,7 +73,7 @@ see.nbin.tck <-function ()
 
 see.nbincdf.tck <- function () 
 {
-  old.par <- par(no.readonly = TRUE)
+#  old.par <- par(no.readonly = TRUE)
     if (!exists("slider.env")) 
         slider.env <- NULL
     suppressWarnings(rm(slider.env))
@@ -147,5 +147,5 @@ see.nbincdf.tck <- function ()
         side = "left")
     tkpack(tkbutton(m, text = "Exit", command = function() tkdestroy(m)), 
         side = "right")
-    on.exit(par(old.par))
+#    on.exit(par(old.par))
 }
