@@ -1,6 +1,6 @@
 see.ttest.tck <- function () 
 {
-
+  old.par <- par(no.readonly = TRUE)
         tclRequire("BWidget")
     if (!exists("slider.env")) 
         slider.env <- NULL; suppressWarnings(rm(slider.env)); slider.env <<- new.env()# Dummy to trick R CMD check
@@ -118,4 +118,5 @@ var.equal<-tclVar(0)
         side = "left")
     tkpack(tkbutton(m, text = "Exit", command = function() tkdestroy(m)), 
         side = "right")
-}
+    on.exit(par(old.par))
+    }
